@@ -4,4 +4,4 @@ from .dimension_definition import DimensionDefinition
 from .pipeline_definition import PipelineDefinition
 from .variable_definition import VariableDefinition
 from .dataset_definition import DatasetDefinition
-from .quality_test_definition import QualityTestDefinition
+from .quality_manager_definition import QualityManagerDefinition
