@@ -3,7 +3,7 @@ class Keys:
     PIPELINE = 'pipeline'
     DATASET_DEFINITION = 'dataset_definition'
     DEFAULTS = 'variable_defaults'
-    QC_TESTS = 'quality_management'
+    QUALITY_MANAGEMENT = 'quality_management'
     ATTRIBUTES = 'attributes'
     DIMENSIONS = 'dimensions'
     VARIABLES = 'variables'
