@@ -4,7 +4,7 @@ import xarray as xr
 from typing import Dict, List, Union
 from .pipeline import Pipeline
 from tsdat.io.filehandlers import FileHandler
-from tsdat.qc import QC
+from tsdat.qc import QualityManagement
 from tsdat.utils import DSUtil
 from tsdat.config import DatasetDefinition, VariableDefinition
 from .pipeline import Pipeline
@@ -33,12 +33,11 @@ class IngestPipeline(Pipeline):
 
             # Standardize the dataset and apply corrections / customizations
             dataset = self.standardize_dataset(raw_dataset_mapping)
-            dataset = self.hook_apply_corrections(dataset, raw_dataset_mapping)
             dataset = self.hook_customize_dataset(dataset, raw_dataset_mapping)
 
             # Apply quality control / quality assurance to the dataset.
             previous_dataset = self.get_previous_dataset(dataset)
-            dataset = QC.apply_tests(dataset, self.config, previous_dataset)
+            dataset = QualityManagement.run(dataset, self.config, previous_dataset)
 
             # Apply any final touches to the dataset and persist the dataset
             dataset = self.hook_finalize_dataset(dataset)
@@ -46,36 +45,13 @@ class IngestPipeline(Pipeline):
 
             # Hook to generate custom plots
             self.hook_generate_and_persist_plots(dataset)
-
-    def hook_apply_corrections(self, dataset: xr.Dataset, raw_mapping: Dict[str, xr.Dataset]) -> xr.Dataset:
-        """-------------------------------------------------------------------
-        Pipeline hook that can be used to apply standard corrections for the 
-        instrument/measurement or calibrations. This method is called
-        immediately after the dataset is converted to standard format and
-        before any QC tests are applied.
-
-        If corrections are applied, then the `corrections_applied` attribute
-        should be updated on the variable(s) that this method applies
-        corrections to.
-
-        Args:
-        ---
-            dataset (xr.Dataset):   A standardized xarray dataset where the 
-                                    variable names correspond with the output 
-                                    variable names from the config file.
-            raw_mapping (Dict[str, xr.Dataset]):    The raw dataset mapping.
-        Returns:
-        ---
-            xr.Dataset: The input xarray dataset with corrections applied.
-        -------------------------------------------------------------------"""
-        return dataset
     
     def hook_customize_dataset(self, dataset: xr.Dataset, raw_mapping: Dict[str, xr.Dataset]) -> xr.Dataset:
         """-------------------------------------------------------------------
         Hook to allow for user customizations to the standardized dataset such
         as inserting a derived variable based on other variables in the
         dataset.  This method is called immediately after the apply_corrections
-        hook and before any QC tests are applied.
+        hook and before Quality Management occurs.
 
         Args:
         ---
@@ -122,7 +98,7 @@ class IngestPipeline(Pipeline):
     def hook_finalize_dataset(self, dataset: xr.Dataset) -> xr.Dataset:
         """-------------------------------------------------------------------
         Hook to apply any final customizations to the dataset before it is
-        saved. This hook is called after quality tests have been applied.
+        saved. This hook is called after Quality Management has occured.
 
         Args:
             dataset (xr.Dataset): The dataset to finalize.
@@ -135,7 +111,7 @@ class IngestPipeline(Pipeline):
     def hook_generate_and_persist_plots(self, dataset: xr.Dataset) -> None:
         """-------------------------------------------------------------------
         Hook to allow users to create plots from the xarray dataset after 
-        processing and QC have been applied and just before the dataset is
+        the dataset has been finalized and just before the dataset is
         saved to disk.
 
         To save on filesystem space (which is limited when running on the
