@@ -1,12 +1,14 @@
-import datetime
 import mimetypes
+
+import datetime
+import matplotlib.pyplot as plt
+import numpy as np
+import pandas as pd
 import os
+import xarray as xr
 from typing import List, Dict, Tuple, Union
 
 import act
-import matplotlib.pyplot as plt
-import numpy as np
-import xarray as xr
 from tsdat.constants import ATTS
 
 # Note that we can't use these in the type hints because
@@ -22,6 +24,12 @@ class DSUtil:
     Provides helper functions for xarray.Dataset
     -------------------------------------------------------------------"""
 
+    @staticmethod
+    def record_corrections_applied(ds: xr.Dataset, variable: str, correction: str):
+        corrections = ds[variable].attrs.get(ATTS.CORRECTIONS_APPLIED, [])
+        corrections.append(correction)
+        ds[variable].attrs[ATTS.CORRECTIONS_APPLIED] = corrections
+
     @staticmethod
     def datetime64_to_string(datetime64: Union[np.ndarray, np.datetime64]) -> Tuple[str, str]:
         datetime = act.utils.datetime64_to_datetime()[0]
@@ -33,15 +41,7 @@ class DSUtil:
         Converts each datetime64 value to a timestamp in same units as
         the variable.
         -------------------------------------------------------------------"""
-        # First we need to get the units of the time variable.
-        # Since this is a time array, we assume it will be one dimensional, so
-        # we use the first data point to find out the type.
-        units = np.datetime_data(variable_data[0])[0]  # datetime_data produces: ('ns', 1)
-
-        # Compute the timestamp
-        ts = (variable_data - np.datetime64('1970-01-01T00:00:00Z', units)) / np.timedelta64(1, units)
-        return ts
-
+        return variable_data.astype(pd.Timestamp).astype(np.int64)
 
     @staticmethod
     def get_datastream_name(ds: xr.Dataset = None, config=None) -> str:
@@ -57,10 +57,10 @@ class DSUtil:
             str: The datastream name
         -------------------------------------------------------------------"""
         assert(ds is not None or config is not None)
-        if ds is not None and "datastream" in ds.attrs:
-            return ds.attrs["datastream"]
+        if ds is not None and "datastream_name" in ds.attrs:
+            return ds.attrs["datastream_name"]
         elif config :
-            return config.dataset_definition.datastream
+            return config.dataset_definition.datastream_name
         return None
 
     @staticmethod
@@ -312,7 +312,7 @@ class DSUtil:
         return f"{datastream_name}.{date}.{time}.{plot_description}.{extension}"
 
     @staticmethod
-    def get_dataset_filename(dataset: xr.Dataset) -> str:
+    def get_dataset_filename(dataset: xr.Dataset, file_extension=".nc") -> str:
         """-------------------------------------------------------------------
         Given an xarray dataset this function will return the base filename of
         the dataset according to MHkiT-Cloud data standards. The base filename
@@ -323,13 +323,14 @@ class DSUtil:
         Args:
             dataset (xr.Dataset):   The dataset whose filename should be
                                     generated.
+            file_extension (str):   The file extension to use.  Defaults to .nc
 
         Returns:
             str: The base filename of the dataset.
         -------------------------------------------------------------------"""
         datastream_name = DSUtil.get_datastream_name(dataset)
         start_date, start_time = DSUtil.get_start_time(dataset)
-        return f"{datastream_name}.{start_date}.{start_time}.nc"
+        return f"{datastream_name}.{start_date}.{start_time}{file_extension}"
 
     @staticmethod
     def get_raw_filename(raw_dataset: xr.Dataset, old_filename: str, config) -> str:
@@ -352,8 +353,7 @@ class DSUtil:
             str: The standardized filename of the raw file.
         -------------------------------------------------------------------"""
         original_filename = os.path.basename(old_filename)
-        b_datastream_name = DSUtil.get_datastream_name(config=config)
-        raw_datastream_name = b_datastream_name[:-2] + "00"
+        raw_datastream_name = config.pipeline_definition.input_datastream_name
         time_var = config.dataset_definition.get_variable('time')
         start_date, start_time = DSUtil.get_raw_start_time(raw_dataset, time_var)
         return f"{raw_datastream_name}.{start_date}.{start_time}.raw.{original_filename}"
@@ -400,7 +400,7 @@ class DSUtil:
         return datastream_name
 
     @staticmethod
-    def get_datastream_directory(datastream_name: str, root: str = None) -> str:
+    def get_datastream_directory(datastream_name: str, root: str = "") -> str:
         """-------------------------------------------------------------------
         Given the datastream_name and an optional root, returns the path to
         where the datastream should be located. Does NOT create the directory
@@ -417,8 +417,7 @@ class DSUtil:
                     located.
         -------------------------------------------------------------------"""
         location_id = datastream_name.split(".")[0]
-        _root = "" if not root else root
-        return os.path.join(_root, location_id, datastream_name)
+        return os.path.join(root, location_id, datastream_name)
 
     @staticmethod
     def is_image(filename: str) -> bool:
